#
# spec file for package perl-gettext
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-gettext
Version:        1.07
Release:        1.1
%define cpan_name gettext
Summary:        Message Handling Functions
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://search.cpan.org/dist/gettext/
Source0:        https://www.cpan.org/authors/id/P/PV/PVANDRY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
The gettext module permits access from perl to the gettext() family of
functions for retrieving message strings from databases constructed to
internationalize software.

* $d = Locale::gettext->domain(DOMAIN)

* $d = Locale::gettext->domain_raw(DOMAIN)

  Creates a new object for retrieving strings in the domain *DOMAIN* and
  returns it. 'domain' requests that strings be returned as Perl strings
  (possibly with wide characters) if possible while 'domain_raw' requests
  that octet strings directly from functions like 'dgettext()'.

* $d->get(MSGID)

  Calls 'dgettext()' to return the translated string for the given *MSGID*.

* $d->cget(MSGID, CATEGORY)

  Calls 'dcgettext()' to return the translated string for the given *MSGID*
  in the given *CATEGORY*.

* $d->nget(MSGID, MSGID_PLURAL, N)

  Calls 'dngettext()' to return the translated string for the given *MSGID*
  or *MSGID_PLURAL* depending on *N*.

* $d->ncget(MSGID, MSGID_PLURAL, N, CATEGORY)

  Calls 'dngettext()' to return the translated string for the given *MSGID*
  or *MSGID_PLURAL* depending on *N* in the given *CATEGORY*.

* $d->dir([NEWDIR])

  If *NEWDIR* is given, calls 'bindtextdomain' to set the name of the
  directory where messages for the domain represented by '$d' are found.
  Returns the (possibly changed) current directory name.

* $d->codeset([NEWCODE])

  For instances created with 'Locale::gettext->domain_raw', manuiplates the
  character set of the returned strings. If *NEWCODE* is given, calls
  'bind_textdomain_codeset' to set the character encoding in which messages
  for the domain represented by '$d' are returned. Returns the (possibly
  changed) current encoding name.

gettext(), dgettext(), and dcgettext() attempt to retrieve a string
matching their 'msgid' parameter within the context of the current locale.
dcgettext() takes the message's category and the text domain as parameters
while dgettext() defaults to the LC_MESSAGES category and gettext()
defaults to LC_MESSAGES and uses the current text domain. If the string is
not found in the database, then 'msgid' is returned.

ngettext(), dngettext(), and dcngettext() function similarily but implement
differentiation of messages between singular and plural. See the
documentation for the corresponding C functions for details.

textdomain() sets the current text domain and returns the previously active
domain.

_bindtextdomain(domain, dirname)_ instructs the retrieval functions to look
for the databases belonging to domain 'domain' in the directory 'dirname'

_bind_textdomain_codeset(domain, codeset)_ instructs the retrieval
functions to translate the returned messages to the character encoding
given by *codeset* if the encoding of the message catalog is known.

%prep
%setup -q -n Locale-%{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
# Testsuite fails with LANG=C.UTF-8 and glibc 2.39
LANG=en_US.UTF-8 %{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc README

%changelog
* Fri Feb  2 2024 Ana Guerrero <ana.guerrero@suse.com>
- Run testsuite with locale LANG=en_US.UTF. It fails otherwise with
  glibc 2.39
* Sat Jun 25 2016 coolo@suse.com
- update to 1.07
  Fix test failures caused by $LANGUAGE being set
- remove perl-gettext-1.05-POSIX.diff
* Mon Sep 21 2015 coolo@suse.com
- updated to 1.06
  Bugfix: #104667 Makefile.PL libaries need to be listed after .o files
  Bugfix: #104668 ensure availability of locale API, correct typo in documentation
  Add META.yml (Fixes #91921)
* Wed Feb 27 2013 coolo@suse.com
- update license to new format
* Thu Nov 17 2011 coolo@suse.com
- use original tar
* Mon Apr 11 2011 chris@computersalat.de
- recreated by cpanspec 1.78.03
- removed old Obsoletes/Provides perl_gtx
* Sun Apr 10 2011 crrodriguez@opensuse.org
- USe perl macros to generate filelist
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Wed Jan 30 2008 pth@suse.de
- Fix bug reference.
* Tue Jan 29 2008 anicka@suse.de
- fix mismatched prototypes [bnc#353715]
- fix specfile (rpmlint warnings), enable tests
* Sun May 27 2007 rguenther@suse.de
- add perl BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jul 11 2005 schubi@suse.de
- update to 1.05
* Fri Apr 15 2005 schubi@suse.de
- update to 1.04
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 schwab@suse.de
- Update specfile.
* Tue Jun 17 2003 choeger@suse.de
- updated filelist
* Thu Aug  8 2002 mls@suse.de
- use sitearch macro
* Wed Nov 15 2000 ro@suse.de
- use BuildRoot
* Wed Nov 15 2000 ro@suse.de
- renamed package perl_gtx to perl-gettext
* Wed Sep 20 2000 schwab@suse.de
- Fix missing declarations.
* Wed May 31 2000 choeger@suse.de
- first version, 1.01
